@@ -1,9 +1,12 @@
 package Music::Intervals;
 our $AUTHORITY = 'cpan:GENE';
+
 # ABSTRACT: Mathematical breakdown of musical intervals
+
 use strict;
 use warnings;
-our $VERSION = '0.0504';
+
+our $VERSION = '0.0505';
 
 use Moo;
 use Algorithm::Combinatorics qw( combinations );
@@ -278,7 +281,7 @@ Music::Intervals - Mathematical breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0504
+version 0.0505
 
 =head1 SYNOPSIS
 
@@ -321,22 +324,14 @@ version 0.0504
 
 =head1 DESCRIPTION
 
-A C<Music::Intervals> object shows the mathematical break-down of musical
+A C<Music::Intervals> object shows the mathematical break-down of musical notes,
 intervals and chords.
 
-This module reveals the "guts" of chords within a given tonality.  By guts I
-mean, the measurements of the notes and the intervals between them.
-
-* This module only handles equal temperament for the 12-tone scale only. *
+This module reveals the "guts" within a given tonality.  And by guts I mean, the
+measurements of the notes and the intervals between them.
 
 =head1 ATTRIBUTES
 
-=head2 cents
-
-Show divisions of the octave.
-
-Default: 0
-
 =head2 chords
 
 Show chord names.
@@ -367,6 +362,12 @@ Show integer notation.
 
 Default: 0
 
+=head2 cents
+
+Show the logarithmic units of measure.
+
+Default: 0
+
 =head2 freqs
 
 Show frequencies.
